Query API over the embedded catalog CSV (1,008 rows).
The raw file is available in the crate sources (data/) and mirrors the CC BY 4.0
dataset published on Zenodo by
TableTemplates.
Structs
- Category
Stats - Aggregated demand for one category.
- Row
- One keyword of the catalog.
Functions
- all
- Every row of the catalog, in file order.
- by_
category - Rows of one category (slug, e.g.
bookkeeping-accounting), ordered by volume. - categories
- The 16 categories with aggregated stats, ordered by combined volume (descending).
- search
- Rows whose keyword contains
needle(case-insensitive), ordered by volume. - top
- The
nhighest-volume keywords. - with_
free_ template - Rows that have a free, no-signup implementation, ordered by volume.